==> viha-5.15.tar.gz: viha-5.15/kadonnut0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "kadonnut";
$file = basename(__FILE__);

include "common.php";
include "loytynyt-ok.php"; # sic!

echo "
<html>
<head>
 <title>VIHA - Kadonneiden henkiliden siirrot</title>
</head>
" . body_bgcolor() . "
<h1>Kadonneiden henkiliden siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$lapsi_tila_id = get_nro('lapsi_tila_id');
$kello = get_txt('kello');
$nimi = get_txt('nimi');
$ika = get_txt('ika');
$sukupuoli = get_txt('sukupuoli');

$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

# apply some magic to all time fields.
$kello = maaginen_kello($kello);

if (($save != '') && saa_tehda("$file:save")) {
  $ret = loytynyt0_save_ok($herja,$id,$alue_id,$paivystys_id,$lapsi_tila_id,
			   $kello,$nimi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE $table
SET alue_id = $alue_id,
    paivystys_id=$paivystys_id,
    lapsi_tila_id=$lapsi_tila_id,
    kello='$kello',
    nimi='$nimi',
    ika='$ika',
    sukupuoli='$sukupuoli',
    ts='$now'
WHERE id=$id
";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    $clear = "SISINEN";
    taktinen_loki("Pivitetty kadonnutta $nimi, tila "
		  . ota_lapsi_tila($lapsi_tila_id));
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = loytynyt_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $tmp_lapsi_tila_id =
      ota_yksi("SELECT lapsi_tila_id FROM $table WHERE id = $id");
    taktinen_loki("Poistetaan kadonnutta "
		  . ota_kadonnut_nimi($id)
		  . ", tila " . ota_lapsi_tila($tmp_lapsi_tila_id));
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot poistettu.\n";
    $clear = "SISINEN";
    loki($sql);
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $alue_id = 1;
    $paivystys_id = 1;
    $lapsi_tila_id = 1;
    $kello = '';
    $nimi = '';
    $ika = '';
    $sukupuoli = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = loytynyt_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

if (! $readonly) {
  echo "<p>Kellonaikojen sytss on taikaa: Kellonajan voi sytt muodossa
HH:MM. Myskin +MM tai -MM - tyyppiset sytt ovat mahdollisia.
Jos sytt jotain muuta niin ko. kohtaan tulee sytthetken kellonaika.
";
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $sql = "
SELECT alue_id, paivystys_id, lapsi_tila_id, kello, nimi, ika, sukupuoli
FROM $table
WHERE id = $id
";
  $result = my_mysql_query($sql);
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $lapsi_tila_id = $a['lapsi_tila_id'];
  $kello = $a['kello'];
  $nimi = $a['nimi'];
  $ika = $a['ika']; 
  $sukupuoli = $a['sukupuoli']; 
  # apply some magic to all time fields.
  $kello = maaginen_kello($kello);
}

echo "<tr><td>Id:<td>";
if ($id == "0") {
  echo "(ei ole)\n";
  $lapsi_tila_id = 2;
} else {
  echo "$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("alue_id", $alue_id, "alue", "id", "alue", "ORDER BY alue");
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("paivystys_id", $paivystys_id, "paivystys", "id", "nimi",
	      "ORDER BY nimi");
}

echo "<tr><td>Tila:<td>";
if ($readonly) {
  echo etsi_teksti("lapsi_tila_id", $lapsi_tila_id, "lapsi_tila", "id",
		    "lapsi_tila") . "\n";
} else {
  echo "\n";
  tee_valinta("lapsi_tila_id", $lapsi_tila_id, "lapsi_tila", "id",
	      "lapsi_tila", "ORDER BY lapsi_tila");
}

echo "<tr><td>Kello:<td>";
if ($readonly) { echo "$kello\n"; } else {
  echo "<input type=\"text\" name=\"kello\" size=19 maxlength=19";
  echo " value=\"$kello\">
Koska tullut operaation tietoon. HH:MM tai X tai -MM tai +MM.\n";
}

echo "<tr><td>Nimi:<td>";
if ($readonly) { echo "$nimi\n"; } else {
  echo "<input type=\"text\" name=\"nimi\" size=64 maxlength=64";
  echo " value=\"$nimi\">\n";
}

echo "<tr><td>Ik:<td>";
if ($readonly) { echo "$ika\n"; } else {
  echo "<input type=\"text\" name=\"ika\" size=8 maxlength=8";
  echo " value=\"$ika\">\n";
}

echo "<tr><td>Sukupuoli:<td>";
if ($readonly) { echo "$sukupuoli\n"; } else {
  echo "<input type=\"text\" name=\"sukupuoli\" size=8 maxlength=8";
  echo " value=\"$sukupuoli\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable)
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
}

$sql = "
SELECT $table.id,alue.alue,paivystys.nimi AS pnimi,$table.ts,lapsi_tila,
       kello,$table.nimi,ika,sukupuoli
FROM $table,lapsi_tila,paivystys,alue
WHERE lapsi_tila_id = lapsi_tila.id AND paivystys_id = paivystys.id
      AND $table.alue_id = alue.id
ORDER BY $table.ts
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  echo tr_bgcolor()
    . "<TH>Id<TH>Alue<TH>Operaatio<TH>Tila<TH>SPR:n<br>tietoon<TH>Nimi"
    . "<TH>Ik<TH>Sukupuoli\n";
  while ($a = mysql_fetch_array($result)) {
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue;
    echo "<TR><TD>$a[id]",
      "<TD>$a[alue]",
      "<TD>$a[pnimi]",
      "<TD>$a[lapsi_tila]",
      "<TD align=right>", vain_hhmm($a['kello']),
      "<TD>$a[nimi]",
      "<TD>$a[ika]",
      "<TD>$a[sukupuoli]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: kadonnut0.php,v 1.6 2009/05/04 05:17:31 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/kadonnut0.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "kadonnut";
$file = basename(__FILE__);

include "common.php";
include "kadonnut-ok.php";

echo "
<html>
<head>
 <title>VIHA - Kadonneiden henkiliden siirrot</title>
</head>
" . body_bgcolor() . "
<h1>Kadonneiden henkiliden siirrot</h1>
";

hallinnolliset_linkit();

$id = get_nro_0('id');
$alue_id = get_nro_1('alue_id');
$paivystys_id = get_nro_1('paivystys_id');
$lapsi_tila_id = get_nro('lapsi_tila_id');
$kello = get_txt('kello');
$nimi = get_txt('nimi');
$ika = get_txt('ika');
$sukupuoli = get_txt('sukupuoli');

$clear = get_txt('clear');
$save = get_txt('save');
$confirm = get_txt('confirm');
$change = get_txt('change');
$remove = get_txt('remove');

oltava_useita($file);
oltava_sallittu($file, $table, $id);

# apply some magic to all time fields.
$kello = maaginen_kello($kello);

if (($save != '') && saa_tehda("$file:save")) {
  $ret = kadonnut0_save_ok($herja,$id,$alue_id,$paivystys_id,$lapsi_tila_id,
			   $kello,$nimi);
  $clear = "SAVE";
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "
UPDATE $table
SET alue_id = $alue_id,
    paivystys_id=$paivystys_id,
    lapsi_tila_id=$lapsi_tila_id,
    kello='$kello',
    nimi='$nimi',
    ika='$ika',
    sukupuoli='$sukupuoli',
    ts='$now'
WHERE id=$id
";
    $result = my_mysql_query ($sql);
    $clear = "SISINEN";
    taktinen_loki("Pivitetty kadonnutta $nimi, tila "
		  . ota_lapsi_tila($lapsi_tila_id));
    loki($sql);
    tehty("Pivitetty kadonneen henkiln $nimi tietoja.");
  }
  p_herja($ret,$herja);
 }

if (($confirm != '') && saa_tehda("$file:confirm")) {
  $ret = kadonnut_remove_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $tmp_nimi = tab_col_id("kadonnut","nimi",$id);
    $tmp_lapsi_tila_id =
      ota_yksi("SELECT lapsi_tila_id FROM $table WHERE id = $id");
    taktinen_loki("Poistetaan kadonnutta "
		  . ota_kadonnut_nimi($id)
		  . ", tila " . ota_lapsi_tila($tmp_lapsi_tila_id));
    $sql = "DELETE FROM $table WHERE id = $id";
    $result = my_mysql_query ($sql);
    $clear = "SISINEN";
    loki($sql);
    tehty("Poistettu kadonnut henkil $nimi.");
  }
  p_herja($ret,$herja);
 }

if ($clear != '') {
    $id = "0";
    $alue_id = 1;
    $paivystys_id = 1;
    $lapsi_tila_id = 1;
    $kello = '';
    $nimi = '';
    $ika = '';
    $sukupuoli = '';
}

# readonly tells if the fields are readonly. if not, they are editable.
if ($remove != '') { $readonly = 1; } else { $readonly = 0; }

# removable tells if we can actually remove this record
if ($remove != '') {
  $removable = 0;
  $ret = loytynyt_remove_ok($herja,$id,false);
  if ($ret != 2) {
    $removable = 1;
  }
  p_herja($ret,$herja);
 }

if (! $readonly) {
  echo "<p>Kellonajan voi sytt muodossa
HH:MM. Myskin +MM tai -MM - tyyppiset sytt ovat mahdollisia.
Jos sytt jotain muuta niin ko. kohtaan tulee sytthetken kellonaika.
";
}

echo "<form action=\"\" method=\"GET\">\n";
echo "<p><table border=0>\n";

if ($id != "0") {
  $sql = "
SELECT alue_id, paivystys_id, lapsi_tila_id, kello, nimi, ika, sukupuoli
FROM $table
WHERE id = $id
";
  $result = my_mysql_query($sql);
  $a = mysql_fetch_array($result);
  $alue_id = $a['alue_id'];
  $paivystys_id = $a['paivystys_id'];
  $lapsi_tila_id = $a['lapsi_tila_id'];
  $kello = $a['kello'];
  $nimi = $a['nimi'];
  $ika = $a['ika']; 
  $sukupuoli = $a['sukupuoli']; 
  # apply some magic to all time fields.
  $kello = maaginen_kello($kello);
}

echo "<tr><td>Id:<td>";
if ($id == "0") {
  echo "(ei ole)\n";
  $lapsi_tila_id = 2;
} else {
  echo "$id\n";
}
echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

echo "<tr><td>Alue:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("alue","",$alue_id)
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("alue_id", $alue_id, "alue", "id", "alue", "ORDER BY alue");
}

echo "<tr><td>Operaatio:";
if ($readonly) {
  echo "<td>"
    . tab_col_id("paivystys","nimi",$paivystys_id)
    . "\n";
} else {
  echo "<td>\n";
  tee_valinta("paivystys_id", $paivystys_id, "paivystys", "id", "nimi",
	      "ORDER BY nimi");
}

echo "<tr><td>Tila:<td>";
if ($readonly) {
  echo etsi_teksti("lapsi_tila_id", $lapsi_tila_id, "lapsi_tila", "id",
		    "lapsi_tila") . "\n";
} else {
  echo "\n";
  tee_valinta("lapsi_tila_id", $lapsi_tila_id, "lapsi_tila", "id",
	      "lapsi_tila", "ORDER BY lapsi_tila");
}

echo "<tr><td>Kello:<td>";
if ($readonly) { echo "$kello\n"; } else {
  echo "<input type=\"text\" name=\"kello\" size=19 maxlength=19";
  echo " value=\"$kello\">
Koska tullut operaation tietoon. HH:MM tai X tai -MM tai +MM.\n";
}

echo "<tr><td>Nimi:<td>";
if ($readonly) { echo "$nimi\n"; } else {
  echo "<input type=\"text\" name=\"nimi\" size=64 maxlength=64";
  echo " value=\"$nimi\">\n";
}

echo "<tr><td>Ik:<td>";
if ($readonly) { echo "$ika\n"; } else {
  echo "<input type=\"text\" name=\"ika\" size=8 maxlength=8";
  echo " value=\"$ika\">\n";
}

echo "<tr><td>Sukupuoli:<td>";
if ($readonly) { echo "$sukupuoli\n"; } else {
  echo "<input type=\"text\" name=\"sukupuoli\" size=8 maxlength=8";
  echo " value=\"$sukupuoli\">\n";
}

echo "</table>\n";

if ($change != "") {
  echo "<input type=\"submit\" name=\"save\" value=\"TALLENNA\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
} elseif ($remove != "") {
  if ($removable)
    echo "<input type=\"submit\" name=\"confirm\" value=\"VAHVISTA POISTO\">\n";
  echo "<input type=\"submit\" name=\"clear\" value=\"PERUUTA\">\n";
}

$sql = "
SELECT $table.id,alue.alue,paivystys.nimi AS pnimi,$table.ts,lapsi_tila,
       kello,$table.nimi,ika,sukupuoli
FROM $table,lapsi_tila,paivystys,alue
WHERE lapsi_tila_id = lapsi_tila.id AND paivystys_id = paivystys.id
      AND $table.alue_id = alue.id
ORDER BY $table.ts
";
$result = my_mysql_query($sql);
if ($result) {
  echo "<p><TABLE BORDER=1>\n";
  tr_reset();
  echo tr_vaalsin()
    . "<TH>Id<TH>Alue<TH>Operaatio<TH>Tila<TH>Tullut<br>tietoon<TH>Nimi"
    . "<TH>Ik<TH>Sukupuoli\n";
  while ($a = mysql_fetch_array($result)) {
    if (permission_tab($herja,$table,$a['id'],false) == 2)
      continue;
    echo tr() . "<TD>$a[id]",
      "<TD>$a[alue]",
      "<TD>$a[pnimi]",
      "<TD>$a[lapsi_tila]",
      "<TD align=right>", vain_hhmm($a['kello']),
      "<TD>$a[nimi]",
      "<TD>$a[ika]",
      "<TD>$a[sukupuoli]";
    if ($id == "0") {
      echo "<td><a href=\"$file?id=$a[id]&change=MUUTA\">MUUTA</a>\n";
      echo "<td><a href=\"$file?id=$a[id]&remove=POISTA\">POISTA</a>\n";
    }
  }
  echo "</TABLE>";
 }

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: kadonnut0.php,v 1.11 2009/09/29 16:09:15 riku Exp $ -->
